# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1/proto/asset_service.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.asset_v1.proto import (
    assets_pb2 as google_dot_cloud_dot_asset__v1_dot_proto_dot_assets__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import expr_pb2 as google_dot_type_dot_expr__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/asset_v1/proto/asset_service.proto",
    package="google.cloud.asset.v1",
    syntax="proto3",
    serialized_options=b"\n\031com.google.cloud.asset.v1B\021AssetServiceProtoP\001Z:google.golang.org/genproto/googleapis/cloud/asset/v1;asset\252\002\025Google.Cloud.Asset.V1\312\002\025Google\\Cloud\\Asset\\V1",
    serialized_pb=b'\n/google/cloud/asset_v1/proto/asset_service.proto\x12\x15google.cloud.asset.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a(google/cloud/asset_v1/proto/assets.proto\x1a#google/longrunning/operations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16google/type/expr.proto"\x8d\x02\n\x13\x45xportAssetsRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x63loudasset.googleapis.com/Asset\x12-\n\tread_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12\x38\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32".google.cloud.asset.v1.ContentType\x12?\n\routput_config\x18\x05 \x01(\x0b\x32#.google.cloud.asset.v1.OutputConfigB\x03\xe0\x41\x02"\x81\x01\n\x14\x45xportAssetsResponse\x12-\n\tread_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\routput_config\x18\x02 \x01(\x0b\x32#.google.cloud.asset.v1.OutputConfig"\xed\x01\n\x1c\x42\x61tchGetAssetsHistoryRequest\x12\x37\n\x06parent\x18\x01 \x01(\tB\'\xe0\x41\x02\xfa\x41!\x12\x1f\x63loudasset.googleapis.com/Asset\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12=\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32".google.cloud.asset.v1.ContentTypeB\x03\xe0\x41\x01\x12@\n\x10read_time_window\x18\x04 \x01(\x0b\x32!.google.cloud.asset.v1.TimeWindowB\x03\xe0\x41\x01"U\n\x1d\x42\x61tchGetAssetsHistoryResponse\x12\x34\n\x06\x61ssets\x18\x01 \x03(\x0b\x32$.google.cloud.asset.v1.TemporalAsset"n\n\x11\x43reateFeedRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x14\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12.\n\x04\x66\x65\x65\x64\x18\x03 \x01(\x0b\x32\x1b.google.cloud.asset.v1.FeedB\x03\xe0\x41\x02"F\n\x0eGetFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"\'\n\x10ListFeedsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02"?\n\x11ListFeedsResponse\x12*\n\x05\x66\x65\x65\x64s\x18\x01 \x03(\x0b\x32\x1b.google.cloud.asset.v1.Feed"y\n\x11UpdateFeedRequest\x12.\n\x04\x66\x65\x65\x64\x18\x01 \x01(\x0b\x32\x1b.google.cloud.asset.v1.FeedB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02"I\n\x11\x44\x65leteFeedRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x63loudasset.googleapis.com/Feed"\xab\x01\n\x0cOutputConfig\x12@\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32%.google.cloud.asset.v1.GcsDestinationH\x00\x12J\n\x14\x62igquery_destination\x18\x02 \x01(\x0b\x32*.google.cloud.asset.v1.BigQueryDestinationH\x00\x42\r\n\x0b\x64\x65stination"C\n\x0eGcsDestination\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x12\x14\n\nuri_prefix\x18\x02 \x01(\tH\x00\x42\x0c\n\nobject_uri"N\n\x13\x42igQueryDestination\x12\x14\n\x07\x64\x61taset\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\x05table\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\r\n\x05\x66orce\x18\x03 \x01(\x08""\n\x11PubsubDestination\x12\r\n\x05topic\x18\x01 \x01(\t"i\n\x10\x46\x65\x65\x64OutputConfig\x12\x46\n\x12pubsub_destination\x18\x01 \x01(\x0b\x32(.google.cloud.asset.v1.PubsubDestinationH\x00\x42\r\n\x0b\x64\x65stination"\xdb\x02\n\x04\x46\x65\x65\x64\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12\x38\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32".google.cloud.asset.v1.ContentType\x12H\n\x12\x66\x65\x65\x64_output_config\x18\x05 \x01(\x0b\x32\'.google.cloud.asset.v1.FeedOutputConfigB\x03\xe0\x41\x02:\x91\x01\xea\x41\x8d\x01\n\x1e\x63loudasset.googleapis.com/Feed\x12\x1fprojects/{project}/feeds/{feed}\x12\x1d\x66olders/{folder}/feeds/{feed}\x12)organizations/{organization}/feeds/{feed} \x01*l\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESOURCE\x10\x01\x12\x0e\n\nIAM_POLICY\x10\x02\x12\x0e\n\nORG_POLICY\x10\x04\x12\x11\n\rACCESS_POLICY\x10\x05\x32\xf0\x08\n\x0c\x41ssetService\x12\xde\x01\n\x0c\x45xportAssets\x12*.google.cloud.asset.v1.ExportAssetsRequest\x1a\x1d.google.longrunning.Operation"\x82\x01\x82\xd3\xe4\x93\x02""\x1d/v1/{parent=*/*}:exportAssets:\x01*\xca\x41W\n*google.cloud.asset.v1.ExportAssetsResponse\x12)google.cloud.asset.v1.ExportAssetsRequest\x12\xb2\x01\n\x15\x42\x61tchGetAssetsHistory\x12\x33.google.cloud.asset.v1.BatchGetAssetsHistoryRequest\x1a\x34.google.cloud.asset.v1.BatchGetAssetsHistoryResponse".\x82\xd3\xe4\x93\x02(\x12&/v1/{parent=*/*}:batchGetAssetsHistory\x12\x7f\n\nCreateFeed\x12(.google.cloud.asset.v1.CreateFeedRequest\x1a\x1b.google.cloud.asset.v1.Feed"*\x82\xd3\xe4\x93\x02\x1b"\x16/v1/{parent=*/*}/feeds:\x01*\xda\x41\x06parent\x12t\n\x07GetFeed\x12%.google.cloud.asset.v1.GetFeedRequest\x1a\x1b.google.cloud.asset.v1.Feed"%\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/{name=*/*/feeds/*}\xda\x41\x04name\x12\x87\x01\n\tListFeeds\x12\'.google.cloud.asset.v1.ListFeedsRequest\x1a(.google.cloud.asset.v1.ListFeedsResponse"\'\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/{parent=*/*}/feeds\xda\x41\x06parent\x12\x82\x01\n\nUpdateFeed\x12(.google.cloud.asset.v1.UpdateFeedRequest\x1a\x1b.google.cloud.asset.v1.Feed"-\x82\xd3\xe4\x93\x02 2\x1b/v1/{feed.name=*/*/feeds/*}:\x01*\xda\x41\x04\x66\x65\x65\x64\x12u\n\nDeleteFeed\x12(.google.cloud.asset.v1.DeleteFeedRequest\x1a\x16.google.protobuf.Empty"%\x82\xd3\xe4\x93\x02\x18*\x16/v1/{name=*/*/feeds/*}\xda\x41\x04name\x1aM\xca\x41\x19\x63loudasset.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\x9c\x01\n\x19\x63om.google.cloud.asset.v1B\x11\x41ssetServiceProtoP\x01Z:google.golang.org/genproto/googleapis/cloud/asset/v1;asset\xaa\x02\x15Google.Cloud.Asset.V1\xca\x02\x15Google\\Cloud\\Asset\\V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_asset__v1_dot_proto_dot_assets__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_type_dot_expr__pb2.DESCRIPTOR,
    ],
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
    name="ContentType",
    full_name="google.cloud.asset.v1.ContentType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTENT_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="RESOURCE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="IAM_POLICY", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ORG_POLICY", index=3, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ACCESS_POLICY", index=4, number=5, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2423,
    serialized_end=2531,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
CONTENT_TYPE_UNSPECIFIED = 0
RESOURCE = 1
IAM_POLICY = 2
ORG_POLICY = 4
ACCESS_POLICY = 5


_EXPORTASSETSREQUEST = _descriptor.Descriptor(
    name="ExportAssetsRequest",
    full_name="google.cloud.asset.v1.ExportAssetsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1.ExportAssetsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037cloudasset.googleapis.com/Asset",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_time",
            full_name="google.cloud.asset.v1.ExportAssetsRequest.read_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1.ExportAssetsRequest.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1.ExportAssetsRequest.content_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1.ExportAssetsRequest.output_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=389,
    serialized_end=658,
)


_EXPORTASSETSRESPONSE = _descriptor.Descriptor(
    name="ExportAssetsResponse",
    full_name="google.cloud.asset.v1.ExportAssetsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="read_time",
            full_name="google.cloud.asset.v1.ExportAssetsResponse.read_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.asset.v1.ExportAssetsResponse.output_config",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=661,
    serialized_end=790,
)


_BATCHGETASSETSHISTORYREQUEST = _descriptor.Descriptor(
    name="BatchGetAssetsHistoryRequest",
    full_name="google.cloud.asset.v1.BatchGetAssetsHistoryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1.BatchGetAssetsHistoryRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A!\022\037cloudasset.googleapis.com/Asset",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_names",
            full_name="google.cloud.asset.v1.BatchGetAssetsHistoryRequest.asset_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1.BatchGetAssetsHistoryRequest.content_type",
            index=2,
            number=3,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_time_window",
            full_name="google.cloud.asset.v1.BatchGetAssetsHistoryRequest.read_time_window",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=793,
    serialized_end=1030,
)


_BATCHGETASSETSHISTORYRESPONSE = _descriptor.Descriptor(
    name="BatchGetAssetsHistoryResponse",
    full_name="google.cloud.asset.v1.BatchGetAssetsHistoryResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="assets",
            full_name="google.cloud.asset.v1.BatchGetAssetsHistoryResponse.assets",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1032,
    serialized_end=1117,
)


_CREATEFEEDREQUEST = _descriptor.Descriptor(
    name="CreateFeedRequest",
    full_name="google.cloud.asset.v1.CreateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1.CreateFeedRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_id",
            full_name="google.cloud.asset.v1.CreateFeedRequest.feed_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1.CreateFeedRequest.feed",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1119,
    serialized_end=1229,
)


_GETFEEDREQUEST = _descriptor.Descriptor(
    name="GetFeedRequest",
    full_name="google.cloud.asset.v1.GetFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1.GetFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1231,
    serialized_end=1301,
)


_LISTFEEDSREQUEST = _descriptor.Descriptor(
    name="ListFeedsRequest",
    full_name="google.cloud.asset.v1.ListFeedsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.asset.v1.ListFeedsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1303,
    serialized_end=1342,
)


_LISTFEEDSRESPONSE = _descriptor.Descriptor(
    name="ListFeedsResponse",
    full_name="google.cloud.asset.v1.ListFeedsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feeds",
            full_name="google.cloud.asset.v1.ListFeedsResponse.feeds",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1344,
    serialized_end=1407,
)


_UPDATEFEEDREQUEST = _descriptor.Descriptor(
    name="UpdateFeedRequest",
    full_name="google.cloud.asset.v1.UpdateFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="feed",
            full_name="google.cloud.asset.v1.UpdateFeedRequest.feed",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.asset.v1.UpdateFeedRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1409,
    serialized_end=1530,
)


_DELETEFEEDREQUEST = _descriptor.Descriptor(
    name="DeleteFeedRequest",
    full_name="google.cloud.asset.v1.DeleteFeedRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1.DeleteFeedRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036cloudasset.googleapis.com/Feed",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1532,
    serialized_end=1605,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
    name="OutputConfig",
    full_name="google.cloud.asset.v1.OutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="gcs_destination",
            full_name="google.cloud.asset.v1.OutputConfig.gcs_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_destination",
            full_name="google.cloud.asset.v1.OutputConfig.bigquery_destination",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1.OutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1608,
    serialized_end=1779,
)


_GCSDESTINATION = _descriptor.Descriptor(
    name="GcsDestination",
    full_name="google.cloud.asset.v1.GcsDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="uri",
            full_name="google.cloud.asset.v1.GcsDestination.uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="uri_prefix",
            full_name="google.cloud.asset.v1.GcsDestination.uri_prefix",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="object_uri",
            full_name="google.cloud.asset.v1.GcsDestination.object_uri",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1781,
    serialized_end=1848,
)


_BIGQUERYDESTINATION = _descriptor.Descriptor(
    name="BigQueryDestination",
    full_name="google.cloud.asset.v1.BigQueryDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="google.cloud.asset.v1.BigQueryDestination.dataset",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="table",
            full_name="google.cloud.asset.v1.BigQueryDestination.table",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.asset.v1.BigQueryDestination.force",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1850,
    serialized_end=1928,
)


_PUBSUBDESTINATION = _descriptor.Descriptor(
    name="PubsubDestination",
    full_name="google.cloud.asset.v1.PubsubDestination",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="topic",
            full_name="google.cloud.asset.v1.PubsubDestination.topic",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1930,
    serialized_end=1964,
)


_FEEDOUTPUTCONFIG = _descriptor.Descriptor(
    name="FeedOutputConfig",
    full_name="google.cloud.asset.v1.FeedOutputConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="pubsub_destination",
            full_name="google.cloud.asset.v1.FeedOutputConfig.pubsub_destination",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.asset.v1.FeedOutputConfig.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1966,
    serialized_end=2071,
)


_FEED = _descriptor.Descriptor(
    name="Feed",
    full_name="google.cloud.asset.v1.Feed",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.asset.v1.Feed.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_names",
            full_name="google.cloud.asset.v1.Feed.asset_names",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="asset_types",
            full_name="google.cloud.asset.v1.Feed.asset_types",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_type",
            full_name="google.cloud.asset.v1.Feed.content_type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="feed_output_config",
            full_name="google.cloud.asset.v1.Feed.feed_output_config",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\215\001\n\036cloudasset.googleapis.com/Feed\022\037projects/{project}/feeds/{feed}\022\035folders/{folder}/feeds/{feed}\022)organizations/{organization}/feeds/{feed} \001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2074,
    serialized_end=2421,
)

_EXPORTASSETSREQUEST.fields_by_name[
    "read_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSREQUEST.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_EXPORTASSETSREQUEST.fields_by_name["output_config"].message_type = _OUTPUTCONFIG
_EXPORTASSETSRESPONSE.fields_by_name[
    "read_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSRESPONSE.fields_by_name["output_config"].message_type = _OUTPUTCONFIG
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_BATCHGETASSETSHISTORYREQUEST.fields_by_name[
    "read_time_window"
].message_type = google_dot_cloud_dot_asset__v1_dot_proto_dot_assets__pb2._TIMEWINDOW
_BATCHGETASSETSHISTORYRESPONSE.fields_by_name[
    "assets"
].message_type = google_dot_cloud_dot_asset__v1_dot_proto_dot_assets__pb2._TEMPORALASSET
_CREATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_LISTFEEDSRESPONSE.fields_by_name["feeds"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name["feed"].message_type = _FEED
_UPDATEFEEDREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_OUTPUTCONFIG.fields_by_name["gcs_destination"].message_type = _GCSDESTINATION
_OUTPUTCONFIG.fields_by_name["bigquery_destination"].message_type = _BIGQUERYDESTINATION
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["gcs_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "gcs_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_OUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _OUTPUTCONFIG.fields_by_name["bigquery_destination"]
)
_OUTPUTCONFIG.fields_by_name[
    "bigquery_destination"
].containing_oneof = _OUTPUTCONFIG.oneofs_by_name["destination"]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri"]
)
_GCSDESTINATION.fields_by_name["uri"].containing_oneof = _GCSDESTINATION.oneofs_by_name[
    "object_uri"
]
_GCSDESTINATION.oneofs_by_name["object_uri"].fields.append(
    _GCSDESTINATION.fields_by_name["uri_prefix"]
)
_GCSDESTINATION.fields_by_name[
    "uri_prefix"
].containing_oneof = _GCSDESTINATION.oneofs_by_name["object_uri"]
_FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"].message_type = _PUBSUBDESTINATION
_FEEDOUTPUTCONFIG.oneofs_by_name["destination"].fields.append(
    _FEEDOUTPUTCONFIG.fields_by_name["pubsub_destination"]
)
_FEEDOUTPUTCONFIG.fields_by_name[
    "pubsub_destination"
].containing_oneof = _FEEDOUTPUTCONFIG.oneofs_by_name["destination"]
_FEED.fields_by_name["content_type"].enum_type = _CONTENTTYPE
_FEED.fields_by_name["feed_output_config"].message_type = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["ExportAssetsRequest"] = _EXPORTASSETSREQUEST
DESCRIPTOR.message_types_by_name["ExportAssetsResponse"] = _EXPORTASSETSRESPONSE
DESCRIPTOR.message_types_by_name[
    "BatchGetAssetsHistoryRequest"
] = _BATCHGETASSETSHISTORYREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchGetAssetsHistoryResponse"
] = _BATCHGETASSETSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name["CreateFeedRequest"] = _CREATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["GetFeedRequest"] = _GETFEEDREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsRequest"] = _LISTFEEDSREQUEST
DESCRIPTOR.message_types_by_name["ListFeedsResponse"] = _LISTFEEDSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateFeedRequest"] = _UPDATEFEEDREQUEST
DESCRIPTOR.message_types_by_name["DeleteFeedRequest"] = _DELETEFEEDREQUEST
DESCRIPTOR.message_types_by_name["OutputConfig"] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name["GcsDestination"] = _GCSDESTINATION
DESCRIPTOR.message_types_by_name["BigQueryDestination"] = _BIGQUERYDESTINATION
DESCRIPTOR.message_types_by_name["PubsubDestination"] = _PUBSUBDESTINATION
DESCRIPTOR.message_types_by_name["FeedOutputConfig"] = _FEEDOUTPUTCONFIG
DESCRIPTOR.message_types_by_name["Feed"] = _FEED
DESCRIPTOR.enum_types_by_name["ContentType"] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportAssetsRequest = _reflection.GeneratedProtocolMessageType(
    "ExportAssetsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTASSETSREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Export asset request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. This can only
          be an organization number (such as “organizations/123”), a
          project ID (such as “projects/my-project-id”), or a project
          number (such as “projects/12345”), or a folder number (such as
          “folders/123”).
      read_time:
          Timestamp to take an asset snapshot. This can only be set to a
          timestamp between the current time and the current time minus
          35 days (inclusive). If not specified, the current time will
          be used. Due to delays in resource data collection and
          indexing, there is a volatile window during which running the
          same query may get different results.
      asset_types:
          A list of asset types of which to take a snapshot for. For
          example: “compute.googleapis.com/Disk”. If specified, only
          matching assets will be returned. See `Introduction to Cloud
          Asset Inventory <https://cloud.google.com/asset-
          inventory/docs/overview>`__ for all supported asset types.
      content_type:
          Asset content type. If not specified, no content but the asset
          name will be returned.
      output_config:
          Required. Output configuration indicating where the results
          will be output to. All results will be in newline delimited
          JSON format.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.ExportAssetsRequest)
    },
)
_sym_db.RegisterMessage(ExportAssetsRequest)

ExportAssetsResponse = _reflection.GeneratedProtocolMessageType(
    "ExportAssetsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTASSETSRESPONSE,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """The export asset response. This message is returned by the
  [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation]
  method in the returned
  [google.longrunning.Operation.response][google.longrunning.Operation.response]
  field.
  
  
  Attributes:
      read_time:
          Time the snapshot was taken.
      output_config:
          Output configuration indicating where the results were output
          to. All results are in JSON format.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.ExportAssetsResponse)
    },
)
_sym_db.RegisterMessage(ExportAssetsResponse)

BatchGetAssetsHistoryRequest = _reflection.GeneratedProtocolMessageType(
    "BatchGetAssetsHistoryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHGETASSETSHISTORYREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Batch get assets history request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. It can only be
          an organization number (such as “organizations/123”), a
          project ID (such as “projects/my-project-id”)“, or a project
          number (such as”projects/12345").
      asset_names:
          A list of the full names of the assets. For example: ``//compu
          te.googleapis.com/projects/my_project_123/zones/zone1/instance
          s/instance1``. See `Resource Names <https://cloud.google.com/a
          pis/design/resource_names#full_resource_name>`__ and `Resource
          Name Format <https://cloud.google.com/asset-
          inventory/docs/resource-name-format>`__ for more info.  The
          request becomes a no-op if the asset name list is empty, and
          the max size of the asset name list is 100 in one request.
      content_type:
          Optional. The content type.
      read_time_window:
          Optional. The time window for the asset history. Both
          start_time and end_time are optional and if set, it must be
          after the current time minus 35 days. If end_time is not set,
          it is default to current timestamp. If start_time is not set,
          the snapshot of the assets at end_time will be returned. The
          returned results contain all temporal assets whose time window
          overlap with read_time_window.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.BatchGetAssetsHistoryRequest)
    },
)
_sym_db.RegisterMessage(BatchGetAssetsHistoryRequest)

BatchGetAssetsHistoryResponse = _reflection.GeneratedProtocolMessageType(
    "BatchGetAssetsHistoryResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHGETASSETSHISTORYRESPONSE,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Batch get assets history response.
  
  
  Attributes:
      assets:
          A list of assets with valid time windows.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.BatchGetAssetsHistoryResponse)
    },
)
_sym_db.RegisterMessage(BatchGetAssetsHistoryResponse)

CreateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "CreateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Create asset feed request.
  
  
  Attributes:
      parent:
          Required. The name of the project/folder/organization where
          this feed should be created in. It can only be an organization
          number (such as “organizations/123”), a folder number (such as
          “folders/123”), a project ID (such as “projects/my-project-
          id”)“, or a project number (such as”projects/12345").
      feed_id:
          Required. This is the client-assigned asset feed identifier
          and it needs to be unique under a specific parent
          project/folder/organization.
      feed:
          Required. The feed details. The field ``name`` must be empty
          and it will be generated in the format of:
          projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.CreateFeedRequest)
    },
)
_sym_db.RegisterMessage(CreateFeedRequest)

GetFeedRequest = _reflection.GeneratedProtocolMessageType(
    "GetFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETFEEDREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Get asset feed request.
  
  
  Attributes:
      name:
          Required. The name of the Feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.GetFeedRequest)
    },
)
_sym_db.RegisterMessage(GetFeedRequest)

ListFeedsRequest = _reflection.GeneratedProtocolMessageType(
    "ListFeedsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """List asset feeds request.
  
  
  Attributes:
      parent:
          Required. The parent project/folder/organization whose feeds
          are to be listed. It can only be using
          project/folder/organization number (such as “folders/12345”)“,
          or a project ID (such as”projects/my-project-id").
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.ListFeedsRequest)
    },
)
_sym_db.RegisterMessage(ListFeedsRequest)

ListFeedsResponse = _reflection.GeneratedProtocolMessageType(
    "ListFeedsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTFEEDSRESPONSE,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      feeds:
          A list of feeds.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.ListFeedsResponse)
    },
)
_sym_db.RegisterMessage(ListFeedsResponse)

UpdateFeedRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Update asset feed request.
  
  
  Attributes:
      feed:
          Required. The new values of feed details. It must match an
          existing feed and the field ``name`` must be in the format of:
          projects/project_number/feeds/feed_id or
          folders/folder_number/feeds/feed_id or
          organizations/organization_number/feeds/feed_id.
      update_mask:
          Required. Only updates the ``feed`` fields indicated by this
          mask. The field mask must not be empty, and it must not
          contain fields that are immutable or only set by the server.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.UpdateFeedRequest)
    },
)
_sym_db.RegisterMessage(UpdateFeedRequest)

DeleteFeedRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteFeedRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEFEEDREQUEST,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """
    Attributes:
      name:
          Required. The name of the feed and it must be in the format
          of: projects/project_number/feeds/feed_id
          folders/folder_number/feeds/feed_id
          organizations/organization_number/feeds/feed_id
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.DeleteFeedRequest)
    },
)
_sym_db.RegisterMessage(DeleteFeedRequest)

OutputConfig = _reflection.GeneratedProtocolMessageType(
    "OutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _OUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Output configuration for export assets destination.
  
  
  Attributes:
      destination:
          Asset export destination.
      gcs_destination:
          Destination on Cloud Storage.
      bigquery_destination:
          Destination on BigQuery. The output table stores the fields in
          asset proto as columns in BigQuery. The resource/iam_policy
          field is converted to a record with each field to a column,
          except metadata to a single JSON string.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.OutputConfig)
    },
)
_sym_db.RegisterMessage(OutputConfig)

GcsDestination = _reflection.GeneratedProtocolMessageType(
    "GcsDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _GCSDESTINATION,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """A Cloud Storage location.
  
  
  Attributes:
      object_uri:
          Required.
      uri:
          The uri of the Cloud Storage object. It’s the same uri that is
          used by gsutil. For example: “gs://bucket_name/object_name”.
          See `Viewing and Editing Object Metadata
          <https://cloud.google.com/storage/docs/viewing-editing-
          metadata>`__ for more information.
      uri_prefix:
          The uri prefix of all generated Cloud Storage objects. For
          example: “gs://bucket_name/object_name_prefix”. Each object
          uri is in format: “gs://bucket_name/object_name_prefix// and
          only contains assets for that type. starts from 0. For example
          :”gs://bucket_name/object_name_prefix/compute.googleapis.com/D
          isk/0" is the first shard of output objects containing all
          compute.googleapis.com/Disk assets. An INVALID_ARGUMENT error
          will be returned if file with the same name
          “gs://bucket_name/object_name_prefix” already exists.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.GcsDestination)
    },
)
_sym_db.RegisterMessage(GcsDestination)

BigQueryDestination = _reflection.GeneratedProtocolMessageType(
    "BigQueryDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _BIGQUERYDESTINATION,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """A BigQuery destination.
  
  
  Attributes:
      dataset:
          Required. The BigQuery dataset in format
          “projects/projectId/datasets/datasetId”, to which the snapshot
          result should be exported. If this dataset does not exist, the
          export call returns an INVALID_ARGUMENT error.
      table:
          Required. The BigQuery table to which the snapshot result
          should be written. If this table does not exist, a new table
          with the given name will be created.
      force:
          If the destination table already exists and this flag is
          ``TRUE``, the table will be overwritten by the contents of
          assets snapshot. If the flag is ``FALSE`` or unset and the
          destination table already exists, the export call returns an
          INVALID_ARGUMEMT error.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.BigQueryDestination)
    },
)
_sym_db.RegisterMessage(BigQueryDestination)

PubsubDestination = _reflection.GeneratedProtocolMessageType(
    "PubsubDestination",
    (_message.Message,),
    {
        "DESCRIPTOR": _PUBSUBDESTINATION,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """A Pub/Sub destination.
  
  
  Attributes:
      topic:
          The name of the Pub/Sub topic to publish to. For example:
          ``projects/PROJECT_ID/topics/TOPIC_ID``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.PubsubDestination)
    },
)
_sym_db.RegisterMessage(PubsubDestination)

FeedOutputConfig = _reflection.GeneratedProtocolMessageType(
    "FeedOutputConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEEDOUTPUTCONFIG,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """Output configuration for asset feed destination.
  
  
  Attributes:
      destination:
          Asset feed destination.
      pubsub_destination:
          Destination on Pub/Sub.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.FeedOutputConfig)
    },
)
_sym_db.RegisterMessage(FeedOutputConfig)

Feed = _reflection.GeneratedProtocolMessageType(
    "Feed",
    (_message.Message,),
    {
        "DESCRIPTOR": _FEED,
        "__module__": "google.cloud.asset_v1.proto.asset_service_pb2",
        "__doc__": """An asset feed used to export asset updates to a
  destinations. An asset feed filter controls what updates are exported.
  The asset feed must be created within a project, organization, or
  folder. Supported destinations are: Pub/Sub topics.
  
  
  Attributes:
      name:
          Required. The format will be
          projects/{project_number}/feeds/{client-
          assigned_feed_identifier} or
          folders/{folder_number}/feeds/{client-
          assigned_feed_identifier} or
          organizations/{organization_number}/feeds/{client-
          assigned_feed_identifier}  The client-assigned feed identifier
          must be unique within the parent project/folder/organization.
      asset_names:
          A list of the full names of the assets to receive updates. You
          must specify either or both of asset_names and asset_types.
          Only asset updates matching specified asset_names and
          asset_types are exported to the feed. For example: ``//compute
          .googleapis.com/projects/my_project_123/zones/zone1/instances/
          instance1``. See `Resource Names <https://cloud.google.com/api
          s/design/resource_names#full_resource_name>`__ for more info.
      asset_types:
          A list of types of the assets to receive updates. You must
          specify either or both of asset_names and asset_types. Only
          asset updates matching specified asset_names and asset_types
          are exported to the feed. For example:
          ``"compute.googleapis.com/Disk"``  See `this topic
          <https://cloud.google.com/asset-inventory/docs/supported-
          asset-types>`__ for a list of all supported asset types.
      content_type:
          Asset content type. If not specified, no content but the asset
          name and type will be returned.
      feed_output_config:
          Required. Feed output configuration defining where the asset
          updates are published to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.asset.v1.Feed)
    },
)
_sym_db.RegisterMessage(Feed)


DESCRIPTOR._options = None
_EXPORTASSETSREQUEST.fields_by_name["parent"]._options = None
_EXPORTASSETSREQUEST.fields_by_name["output_config"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["parent"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["content_type"]._options = None
_BATCHGETASSETSHISTORYREQUEST.fields_by_name["read_time_window"]._options = None
_CREATEFEEDREQUEST.fields_by_name["parent"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed_id"]._options = None
_CREATEFEEDREQUEST.fields_by_name["feed"]._options = None
_GETFEEDREQUEST.fields_by_name["name"]._options = None
_LISTFEEDSREQUEST.fields_by_name["parent"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["feed"]._options = None
_UPDATEFEEDREQUEST.fields_by_name["update_mask"]._options = None
_DELETEFEEDREQUEST.fields_by_name["name"]._options = None
_BIGQUERYDESTINATION.fields_by_name["dataset"]._options = None
_BIGQUERYDESTINATION.fields_by_name["table"]._options = None
_FEED.fields_by_name["name"]._options = None
_FEED.fields_by_name["feed_output_config"]._options = None
_FEED._options = None

_ASSETSERVICE = _descriptor.ServiceDescriptor(
    name="AssetService",
    full_name="google.cloud.asset.v1.AssetService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\031cloudasset.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=2534,
    serialized_end=3670,
    methods=[
        _descriptor.MethodDescriptor(
            name="ExportAssets",
            full_name="google.cloud.asset.v1.AssetService.ExportAssets",
            index=0,
            containing_service=None,
            input_type=_EXPORTASSETSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=b'\202\323\344\223\002""\035/v1/{parent=*/*}:exportAssets:\001*\312AW\n*google.cloud.asset.v1.ExportAssetsResponse\022)google.cloud.asset.v1.ExportAssetsRequest',
        ),
        _descriptor.MethodDescriptor(
            name="BatchGetAssetsHistory",
            full_name="google.cloud.asset.v1.AssetService.BatchGetAssetsHistory",
            index=1,
            containing_service=None,
            input_type=_BATCHGETASSETSHISTORYREQUEST,
            output_type=_BATCHGETASSETSHISTORYRESPONSE,
            serialized_options=b"\202\323\344\223\002(\022&/v1/{parent=*/*}:batchGetAssetsHistory",
        ),
        _descriptor.MethodDescriptor(
            name="CreateFeed",
            full_name="google.cloud.asset.v1.AssetService.CreateFeed",
            index=2,
            containing_service=None,
            input_type=_CREATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b'\202\323\344\223\002\033"\026/v1/{parent=*/*}/feeds:\001*\332A\006parent',
        ),
        _descriptor.MethodDescriptor(
            name="GetFeed",
            full_name="google.cloud.asset.v1.AssetService.GetFeed",
            index=3,
            containing_service=None,
            input_type=_GETFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002\030\022\026/v1/{name=*/*/feeds/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="ListFeeds",
            full_name="google.cloud.asset.v1.AssetService.ListFeeds",
            index=4,
            containing_service=None,
            input_type=_LISTFEEDSREQUEST,
            output_type=_LISTFEEDSRESPONSE,
            serialized_options=b"\202\323\344\223\002\030\022\026/v1/{parent=*/*}/feeds\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateFeed",
            full_name="google.cloud.asset.v1.AssetService.UpdateFeed",
            index=5,
            containing_service=None,
            input_type=_UPDATEFEEDREQUEST,
            output_type=_FEED,
            serialized_options=b"\202\323\344\223\002 2\033/v1/{feed.name=*/*/feeds/*}:\001*\332A\004feed",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteFeed",
            full_name="google.cloud.asset.v1.AssetService.DeleteFeed",
            index=6,
            containing_service=None,
            input_type=_DELETEFEEDREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\030*\026/v1/{name=*/*/feeds/*}\332A\004name",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name["AssetService"] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)
